'use strict';
/**
 * H5 页面通用下载方法
 * 1  微信中：ios android 直接跳转至腾讯应用宝；(andriod 不能统计渠道号)
 * 2  微博：ios 图片提示；android 通过浏览器打开继续下载APK
 * 3  浏览器：ios 跳转到appstore; andriod:直接下载APK
 * 4  关注rrd 和 we 不同域名下跳转；
 * 5  所有上述情况都以最新版本的第三方软件为主；
 *
 * 注意：2中微博下载如果想要显示引导图，请在TPL中引入downapp.tpl，（由于设计没有给到图，所以沿用老图，请下次调用的同学催促下产品提供新图并将此注释删除）
 * Created by qiangran on 17/6/10.
 */

const $ = require("common:widget/lib/jquery/jquery.js");
const glpbCommon = require('glpb-components-common');
const BaseComponent = glpbCommon.BaseComponent;
const utils = BaseComponent.utils;
require("./downapp.scss");


class DownApp {

    constructor(){
        let ua = navigator.userAgent;
        let platform = {
            // android终端或者uc浏览器
            android: ua.indexOf('Android') > -1 || ua.indexOf('Linux') > -1,
            androidVersion : 0,
            // 是否为iPhone或者QQHD浏览器
            iPhone: ua.indexOf('iPhone') > -1 ,
            // 是否iPad
            iPad: ua.indexOf('iPad') > -1,
            //ios version
            iosVersion : 0,
            //windows phone
            wPhone: ua.indexOf('Windows Phone') > -1,
            //是否在 微信 客户端内
            isWeixin : ua.indexOf('MicroMessenger') > -1,
            //是否在 微博 客户端内
            isWeibo: ua.indexOf('Weibo') > -1
        };

        let out = /iPhone OS (\d+)/.exec(ua);

        if(  out ){
            platform.iosVersion = parseInt(out[1], 10);
        }else if( out = /Android (\d+)/.exec(ua) ){
            platform.androidVersion = parseInt( out[1], 10 );
        }
        //不同系统和第三方应用封装对象
        this.platform = platform;

        //判断是是 RRD 还是WE网站域名下载
        const tplConf = utils.getTplConf();
        this.isWeCom = tplConf._isWeCom;

        //定义下载相关的url
        //这里的andriod 没有用到，因为该接口不支持获取ccName,没有屏蔽是以防以后会用到
        this.defaultDownloadUrl = {
            we : {
                "yingyongbao": "http://a.app.qq.com/o/simple.jsp?pkgname=com.we.finance",
                "android": "https://www.we.com/event/download.action?type=apk&appId=we",
                "ios": "https://itunes.apple.com/cn/app/id1234482121?mt=8",
                "schema": "weinvestment://"
            },
            rrd : {
                "yingyongbao": "http://a.app.qq.com/o/simple.jsp?pkgname=com.renrendai.finance",
                "android": "https://m.renrendai.com/mo/about/home/getUrl?version=2.0",
                "ios": "https://itunes.apple.com/cn/app/id883561142?mt=8",
                "schema": "renrendaiinvestment://app.we.com"
            }
        };
    }

    // 下载 没有直接在按钮上绑定click事件而只单纯的提供下载方法 是为了某些页面需要特别处理click事件 比如品友活动添加转化点
    downloadApp(type){
        //尝试调起App，由于iOS上浏览器上会提示"safari打不开该网页，因为网址无效"，在iOS添加"Universal links"前，暂时添加android唤起流程
        if(this.platform.android && type && type == "openApp" ){
            let _this = this;

            let domain = this.isWeCom && this.isWeCom == "true" ? "we" : "rrd";
            this.callNative( this.defaultDownloadUrl[domain].schema, function(isTimeout){
                if( isTimeout ){
                    setTimeout(function(){
                        _this.toDownloadAppHandle();
                    },0);
                }
            } );
        }else{
            this.toDownloadAppHandle();
        }
    }

    //下面代码来自网络,创建一个iframe,延迟后判断是否页面跳转了
    callNative(url, callback){

        let _this = this;
        if (!url) {
            return;
        }
        var node = document.createElement('iframe');
        node.style.display = 'none';
        var body = document.body;
        var timer;
        var clear = function(evt, isTimeout) {
            (typeof callback==='function') &&  callback(isTimeout);
            window.removeEventListener('pagehide', hide, true);
            //window.removeEventListener('pageshow', hide, true);
            if (!node) {
                return;
            }

            node.onload = null;
            body.removeChild(node);
            node = null;

        };
        var hide = function(e){
            clearTimeout(timer);
            //alert('page hide');
            clear(e, false);
        };
        window.addEventListener('pagehide', hide, true);

        if( this.platform.iosVersion >= 9 ){
            node = null;
            location.href = url;

        }else{
            //window.addEventListener('pageshow', hide, true);
            node.onload = clear;
            node.src = url;
            body.appendChild(node);
        }

        var now = +new Date();

        timer = setTimeout(function(){
            timer = setTimeout(function(){
                var newTime = +new Date();
                var duration = newTime - now;
                if( duration > 3000){
                    clear(null, false);
                }else if( ! _this.browserHidden() ){

                    clear(null, true);
                }

            }, 1200);
        }, 60);
    }

    browserHidden() {
        if (typeof document.hidden !== 'undefined') {
            return document.hidden;
        } else if (typeof document.mozHidden !== 'undefined') {
            return document.mozHidden;
        } else if (typeof document.msHidden !== 'undefined') {
            return document.msHidden;
        } else if (typeof document.webkitHidden !== 'undefined') {
            return document.webkitHidden;
        }

        return false;
    };


    //下载具体方法，这里删除了原先直接调起本地native的方法，【老王同意的，有毛毛作证 20170620 下午6：46】
    toDownloadAppHandle(){
        let download = null;

        let platform = this.platform;

        //该地址接口新增参数appId，其中we=>WE APP;rrd=>RRD APP；不写该参数 则默认是RRD APP
        let andriodDownApkUrl = "/mo/about/home/getUrl?version=2.0&appId=rrd";

        //根据isWeCom的值，判断是下载we还是rrd的app
        if (this.isWeCom && this.isWeCom == "true") {
            download = this.defaultDownloadUrl.we;
            andriodDownApkUrl = `${andriodDownApkUrl}&appId=we`;
        } else {
            download = this.defaultDownloadUrl.rrd;
            andriodDownApkUrl = `${andriodDownApkUrl}&appId=rrd`;
        }

        if (platform.wPhone) {
            alert('抱歉，暂不支持您的设备');
            return;
        }

        //微信中
        // IOS 和 android 通过应用宝进行下载
        if (platform.isWeixin) {
            location.replace(download.yingyongbao);
            return;
        }
        //微博中
        // IOS中不能下载，特殊处理，展示引导提示图片
        if (platform.isWeibo) {
            if (platform.iPhone || platform.iPad) {
                let tipImg = "https://m.renrendai.com/cms/58660a17cb02a3105bff2da1/2018/worldCup/open-in-safari.png";
                $(`<div style="position: fixed;top: 0;left: 0;width: 100%;height: 100%;background-color: rgba(0,0,0,0.8); z-index: 9999;"><img src="${tipImg}" style="display:block; width: 7.5rem; height: auto;" /></div>`).appendTo( document.body );
                return;
            }
        }

        //浏览器中 IOS ：跳转appstore;
        //浏览器和微博中 android ：直接下载APK
        if (platform.android) {

            this.downloadAndroid(andriodDownApkUrl);
        } else {
            location.replace(download.ios)
        }

        return false;
    }

    // 安卓下载 不直接调用上面defaultDownloadUrl默认的下载链接 则是因为需要传递ccName（PS：毛毛出品 品质保证）
    downloadAndroid(andriodDownApkUrl){

        var xhr = new XMLHttpRequest();
        var seachconf = utils.getSearchConf();
        var ccName = seachconf.ccName || 'rrdweb';
        let encodeCcName = encodeURIComponent(ccName);
        andriodDownApkUrl = `${andriodDownApkUrl}&ccName=${encodeCcName}`;

        xhr.open('GET', andriodDownApkUrl);
        xhr.onreadystatechange = function(){
            if( xhr.readyState === 4 ){
                if( xhr.status === 200 ){
                    try{
                        var out = JSON.parse(xhr.responseText);
                    }catch(e){
                        out = {
                            status : -1,
                            msg : '解析结果失败'
                        };
                    }
                    if( out && out.status === 0 && out.data && out.data.url ){
                        location.href =  out.data.url;
                    }else{
                        alert('服务器异常,请稍后再试');
                    }
                }
            }
        };
        xhr.send();
    }

};

let downApp = new DownApp();
module.exports =  downApp;
