/**
 * 移动端的 APP 下载按钮, 可以设置 :hover 的样式
 * 如果本地已经安装了APP, 直接打开; 否则跳转到对应的应用市场
 * Created by jess on 2016/10/8.
 */


const glpbCommon = require('glpb-components-common');


const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;

const download = require('../../common-ui/downapp/downapp.js')

//默认配置
let configData;

require('./app-download-btn.scss');

let tpl = "";

const LinkButton = BaseComponent.extend(
    {
        componentName : 'glpb_app_download_button',
        componentNameZh : 'APP下载按钮',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.MOBILE,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                position : 'relative',
                height : '88px',
                width : '6.9rem',
                padding : '0',
                margin : '0 auto',
                fontSize : 'inherit',
                lineHeight : '88px',
                'color|>[DOT]glpb-content' : '#fff',
                'color|>[DOT]glpb-content:hover' : '#fff',
                background : {
                    backgroundColor : 'transparent'
                },
                'background|:hover' : {
                    backgroundColor : 'transparent'
                },
                textAlign : 'center',
                animation : 'none',
                textDecoration : 'none',
                borderRadius : '5px',
                zIndex : 10
            };
        },

        //支持直接下载或者跳转到下载页面
        getDefaultData : function(){
            return {
                'download_type_$$comment' : '下载类型，分为两种：direct（直接下载）；downloadPage（跳到下载页）',
                download_type : 'downloadPage',
                "href_$$comment" : '要跳转的URL地址，默认跳到应用宝（仅在跳到下载页时需要配置且生效，直接下载时，这儿不需要配置）',
                href : 'http://a.app.qq.com/o/simple.jsp?pkgname=com.renrendai.finance',
                'target_$$comment' : '如果是跳到下载页（仅在跳到下载页时需要配置且生效），也要配置新页面打开方式: _blank(新tab页); _self(当前页)',
                target : '_blank',
                'text_$$comment' : '按钮上显示的文字',
                text : '下载APP客户端'
            };
        },

        getDataType : function(){
            return BaseComponent.DATA_TYPES.JSON;
        },

        getData : function(){
            return this.data || {};
        },

        render : function(){
            let currentComponentId = this.componentId;
            let data = this.data;

            if(data.download_type == "downloadPage"){
                //跳转到下载页
                tpl = `<div class="glpb-fn-animate-item"><a class="glpb-content" href="${data.href}" target="${data.target}">${data.text}</a></div>`;
            }else{
                //直接下载
                tpl = `<div class="glpb-fn-animate-item"><span class="glpb-content">${data.text}</span></div>`;
            }

            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass );

            let $content = $('.glpb-content', $el);
            this.$el = $el;
            this.$content = $content;

            configData = this.getData();

            // $content.css( cssStyle );
            this.updateCSSStyle( cssStyle );

            this.setData( data );

        },

        updateCSSStyle : function(cssStyle){
            this.styleManager.update( '#' + this.componentId , cssStyle );
            // this.$content.css( style );
        },

        bindComponentEvent : function(){

            let that = this;

            if( this.isProductionMode() && ! this.eventBinded ){

                this.eventBinded = true;

                this.$content.on('click', function(){download.downloadApp(); } );
            }
        },

        componentWillUnmount : function(){
            if( this.eventBinded ){
                this.$content.off('click', function(){download.downloadApp(); });
            }
            this.$content = null;
        }
    }
);


module.exports = LinkButton;

