const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

const lpService = serviceFactory.getService('lp');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;
require('./inviter-info.scss');

const tpl = `<div class="glpb-inviter-info"><div class="glpb-content"></div></div>`;

const InviterInfo = BaseComponent.extend({
    componentName : 'glpb_we_com_inviter_info',
    componentNameZh : '邀请人信息',
    componentCategory : BaseComponent.CATEGORY.UI,
    platform : BaseComponent.PLATFORM.MOBILE,
    canBeChildOfComponentName : function(){
        return true;
    }
}, {
    getDefaultStyle : function(){
        return {
            background : {
                backgroundColor : 'none'
            },
            padding : '0',
            margin : '0 auto'
        };
    },

    getDefaultData : function(){
        return {
            "text_$$comment" : '显示邀请人信息的文本',
            text: "您的好友XX邀您加入人人贷",
            "color_$$comment" : '文本的颜色, 不填默认为#ffdba3',
            color: "#ffdba3"
        };
    },

    init : function () {
    },

    render : function(){
        let currentComponentId = this.componentId;

        let cssClass = this.getBaseCssClass() + '  ';
        let cssStyle = this.translateStyle( this.style );
        let $el = $(tpl).addClass( cssClass ).css( cssStyle );;
        let $content = $('.glpb-content', $el);

        this.$el = $el;
        this.$content = $content;

        if( ! this.isProductionMode() ){
            //编辑模式, 显示一个图片占位
            $(`<div class="editor-place-holder" >您的好友xx邀您加入人人贷!</div>`).appendTo( $content );
        }
    },

    bindComponentEvent: function () {
        let _this = this;
        let data = this.data || {};
        // 组件需要的数据
        let text = data.text;

        let reqData = {
            shareCode: utils.getSearchConf().share_id
        };

        lpService.pbInviterInfo( reqData ).then( ( reqResult ) => {
            if( reqResult.requestStatus === lpService.STATUS.SUCCESS ){
            let result = reqResult.data;
            if( result.status === 0 ){
                let name = reqResult.data.data;
                text = text.replace('XX', name);

                // 判断是否有邀请人现金标记
                if (text.indexOf('CASH_REWARD_FLAG')) {
                    lpService.pbInviterCash( reqData ).then( ( req ) => {
                        if( req.requestStatus === lpService.STATUS.SUCCESS ){
                            let res = req.data;
                            if (res.status === 0) {
                                let cashData = res.data;
                                text = text.replace('CASH_REWARD_FLAG', cashData.value);
                                this.$content.html(`<div class="inviter-info-text" style="${data.color ? 'color: ' + data.color : ''}">${text}</div>`);
                            }
                        }
                    }).catch( (e) => {
                        alert(e.message);
                    });
                } else {
                    this.$content.html(`<div class="inviter-info-text" style="${data.color ? 'color: ' + data.color : ''}">${text}</div>`);
                }

                return;
            }
            return Promise.reject(new Error(result.message));
        }
        return Promise.reject( new Error('获取邀请人数据异常!'));
        }).catch((e) => {
            alert(e.message);
        });

    }

});

module.exports = InviterInfo;


