/**
 * 出借信息滚动条
 * Created by daifei on 2019/9/10
 */
const glpbCommon = require('glpb-components-common');

const BaseComponent = glpbCommon.BaseComponent;

const utils = BaseComponent.utils;

const serviceFactory = require('../../service/service-factory.js');

const lpService = serviceFactory.getService('lp');

const $ = BaseComponent.$;

const tpl = `<div class="glpb-loan-scroll-bar-item"><div class="glpb-content"></div></div>`;

require('./loan-scroll-bar.scss');
const ScrollBar = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_mo_loan_scroll_bar_box',
        componentNameZh : '出借信息滚动条组件',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.MOBILE,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                width : '6.9rem',
                height : '1.4rem',
                background : {},
                padding : '0.3rem 0.34',
                margin : '0 auto'
            };
        },
        getDefaultData : function(){
            return {
                "totalNum$$comment" : "展示出借人信息总条数默认30条",
                totalNum : 30,
                "planType$$comment" : "展示新手专享(U_NEW)、U享(UPLAN)、优选(PREMIUM)用逗号连接,默认都展示",
                planType : "U_NEW,PREMIUM,UPLAN",
                "fps$$comment" : "每一次动画的时间默认是500ms",
                fpsTime : 500,
                "cardBg$$comment" : '滚动条的背景图片',
                cardImg : 'https://s0.renrendai.com/cms/5864b392e0286a10854d8766/pb/bar.png',
                "cardWidth$$comment":"滚动卡片的宽度",
                cardWidth:'6.28rem',
                "cardHeight$$comment":"滚动卡片的高度",
                cardHeight:'0.8rem',
                "cardPadding$$comment":"滚动卡片的内边距",
                cardPadding:"0 0.32rem",
                "cardMargin$$comment":"滚动卡片的外边距",
                cardMargin:"0.3rem auto",
                'loanInfoColor$$comment':'滚动出借信息颜色',
                loanInfoColor : '#ff8133',
            };
        },
        init : function(){
            this.createDom = this.createDom.bind(this);
            this.startAnimation = this.startAnimation.bind(this);
            this.timer = null;
        },
        render : function(){

            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('.glpb-content', $el);


            this.$el = $el;
            this.$content = $content;

            //这个方法在基类 里面实现了  不需要重新定义了
            this.updateCSSStyle(cssStyle);
            let srollBar = null;
            if( ! this.isProductionMode() ) {
                //编辑模式, 显示一个图片占位
                srollBar = `<div class="sroll-bar"><img class="editor-sroll-bar-place-img" src="https://s0.renrendai.com/cms/5864b392e0286a10854d8766/pb/grape_cms_bar.png" title="滚动出借信息组件占位图片(非真实数据)" /></div>`;
            }

            $(srollBar).appendTo( $content );

        },
        bindComponentEvent : function() {

            let data = this.data || {};
            if( this.isProductionMode() && ! this.eventBinded ) {
                //正式环境才绑定定时器, 并且Ajax请求
                const reqData = {
                    queryNum : data.totalNum,
                    isLP : true,
                    businessCategory : data.planType,
                }
                lpService.getScrollBarData( reqData ).then( ( reqResult ) => {
                    if (reqResult.requestStatus === lpService.STATUS.SUCCESS) {
                        let result = reqResult.data;
                        if (result.status === 0) {
                            const data = result.data;
                            const html = this.createDom(data);
                            this.$content.html(html);
                            this.startAnimation()
                        }
                    }
                })
            }
        },
        //定时器开始
        startAnimation : function(){
            let data = this.data || {};

            let time = data.fpsTime || 500;
            let animationTop = 0;
            const totalHeight = $('.total-list').height();
            const len = $('.total-list li').length;
            const fpsDistance = parseFloat(totalHeight/len);
            if(this.timer){
                //开始前先清除定时器
                clearInterval(this.timer);
            }
            this.timer = setInterval(function(){
                animationTop -= fpsDistance
                animationTop = utils.round(animationTop,3).toFixed(3);
                if(Math.abs(animationTop) > (totalHeight-fpsDistance)){
                    animationTop = 0;
                    $('.total-list').css({top:0});
                }

                $('.total-list').animate({top:animationTop},time);
            },4000)
        },

        //处理数据变成 html
        createDom : function(data){
            let allData = this.data;
            let list = '';
            const nowTime = new Date().getTime();
            if(data && Object.keys(data).length > 0){
                data.forEach(function(index,i){
                    //处理时间
                    const tradeTime = index.tradeTime;
                    const times = nowTime - tradeTime;
                    const oneHours = 60*60*1000;
                    const oneMinute = 60000;
                    let timeText = '';
                    if(times < oneHours){
                        timeText = Math.ceil(times/oneMinute) + '分钟';
                    }else{
                        timeText = Math.floor(times/oneHours) + '小时';
                    }
                    //处理姓名
                    const realName = index.realName || '';
                    let uname = realName.substr(0,1);
                    if(realName.length > 3){
                        uname = realName.substr(0,2);
                    }
                    //处理是先生还是女士
                    let gender = '先生';
                    if(index.gender == 1){
                        gender = '女士';
                    }
                    //处理计划类型
                    let planName = '';
                    switch(index.businessCategory){
                        case 'U_NEW':
                            planName = '新手专享';
                            break;
                        case 'UPLAN':
                            planName = 'U享';
                            break;
                        case 'PREMIUM':
                            planName = '优选';
                            break;
                    }
                    const listStyle = `height:${allData.cardHeight};line-height:${allData.cardHeight};color:${allData.loanInfoColor}`;
                    list += `<li style="${listStyle}">${timeText}前，${uname}${gender}出借${planName}<span class="amount">${index.investAmount}元</span></li>`
                })
            }

            let userListStyle = `width:${allData.cardWidth};height:${allData.cardHeight};padding:${allData.cardPadding};margin:${allData.cardMargin};`;
            if(allData.cardImg){
                userListStyle += `background-image:url(${allData.cardImg});`;
            }
            return `<div class="sroll-bar">
                    <div class="user-list" style="${userListStyle}">
                         <ul class="total-list">${list}</ul>
                    </div>
                </div>`;
        },
        setData : function(data){
            this.data = $.extend( this.data, data );
        },
    }
);

module.exports = ScrollBar;