/**
 * Created by 王半仙 on 2017-10-25.
 * 新手专享-新样式（样式一）
 */

const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

const lpService = serviceFactory.getService('lp');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;

const tpl = `<div class="glpb-newer-item"><div class="glpb-content"></div></div>`;

require('./newer-item-style1.scss');

const editorPlaceHolderImage = 'https://s0.renrendai.com/cms/58647d50e0286a10854d875a/lp/placeholder/newer.png';


const NewerItem = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_mo_lp_register_newer_style1',
        componentNameZh : '新手专享(深色)',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.MOBILE,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                background : {
                    backgroundColor : 'none'
                },
                padding : '0',
                margin : '0 auto'
            };
        },

        getDefaultData : function(){
            return {
                "type_$$comment" : 'u1为1个月的U新标,u3期限3个月的U新标',
                type : 'u1',
                "bgImageUrl_$$comment" : '背景图【图片大小必须为650*250】',
                bgImageUrl : '//m.we.com/cms/58647d50e0286a10854d875a/pagebuilder/u-newer-bg-style1-1029.png',
                "rateColor_$$comment" : '利率的字体颜色',
                rateColor : '#ff7f31',
                "rateText_$$comment": '利率下方文案',
                rateText: '扣费后年利率',
                "lockPeriodText_$$comment": '服务期文案 XX表示期限(XX注意是大写)，从后端取值',
                lockPeriodText: 'XX个月服务期限',
                "lockPeriodColor_$$comment" : '右侧服务期的字体颜色',
                lockPeriodColor : '#333',
                "disTextColor_$$comment" : '字段描述的文字颜色',
                disTextColor : '#666',
                "explain_$$comment" : '服务期下方的文案配置',
                explain : '使用红包，回报更高',
                "minAmountShow_$$comment" : '是否展示最低出借金额【true展示，false不展示，默认不展示】',
                minAmountShow: false,
            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
        },

        render : function(){
            let currentComponentId = this.componentId;

            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('.glpb-content', $el);

            this.$el = $el;
            this.$content = $content;

            if( ! this.isProductionMode() ){
                //编辑模式, 显示一个图片占位
                $(`<img class="editor-place-holder-img" width="100%" src="${editorPlaceHolderImage}" title="新手专享(非真实数据)" />`).appendTo( $content );
            }
        },

        bindComponentEvent : function(){
            let that = this;
            let data = this.data || {};
            let type = data.type;

            if( this.isProductionMode() && ! this.eventBinded ){

                this.eventBinded = true;

                this.querySign = utils.generateQuerySign();

                let reqData = {
                    types : type
                };
                lpService.newerInvest( reqData ).then( ( reqResult ) => {
                    if( reqResult.requestStatus === lpService.STATUS.SUCCESS ){
                        let result = reqResult.data;
                        if( result.status === 0 ){
                            that.setNewerData( result.data );
                            return;
                        }
                        return Promise.reject(new Error(result.message));
                    }
                    return Promise.reject( new Error('获取新手专享数据异常!'));
                })
                    .catch( (e) => {
                        alert(e.message);
                        that.hide();
                    });
            }
        },

        componentWillUnmount : function(){
            this.$content = null;
        },

        setNewerData : function(data){
            let list = data.list;
            list = list || [];
            if( ! list || list.length < 1 ){
                return this.hide();
            }
            let html = this._renderItem( list[0] );
            if( html ){
                this.$content.html( html );
            }else{
                this.hide();
            }
        },

        formatRate:function(rate){
            //格式化利率，保留一位小数
            if (typeof rate == 'number') {
                rate = rate+'';
            }
            let index = rate.indexOf('.');
            rate = rate.substr(0,index+2);
            if( rate && rate.indexOf('.') < 0 ){
                rate += '.0';
            }
            return rate;
        },

        _renderItem : function( financePlanVos ){
            let data = this.data || {};
            let bgImageUrl = data.bgImageUrl;
            let rateColor = data.rateColor;
            let lockPeriodColor = data.lockPeriodColor;
            let disTextColor = data.disTextColor;
            let minAmountShow = data.minAmountShow;
            let rateText = data.rateText;
            let explain = data.explain;
            let filedDom = data.lockPeriodText.replace('XX',financePlanVos.lockPeriod);
            let rateDom = `${financePlanVos.expectedYearRate}<span>%</span>`;
            // if(minAmountShow){
            //     filedDom = `${financePlanVos.lockPeriod}个月服务期限，${financePlanVos.minRegisterAmount}起出借`;
            // }
            let baseInterestRate = this.formatRate(financePlanVos.baseInterestRate);
            let extraInterestRate = this.formatRate(financePlanVos.extraInterestRate);
            if(extraInterestRate != '0.0'){
                rateDom = `${baseInterestRate}<span>%+${extraInterestRate}%</span>`;
            }
            let html = `
                <div class="u-newer-style-wrap" style="background: url('${bgImageUrl}') no-repeat; background-size: 100% 100%;">     
                   <ul class="premium-data fn-clear">
                        <li class="premium-left">
                            <div class="rate" style="color: ${rateColor};">${rateDom}</div>
                            <div class="text" style="color: ${disTextColor};">${rateText}</div>
                        </li>
                        <li class="premium-right">
                            <div class="rate" style="color: ${lockPeriodColor};">${filedDom}</div>
                            <div class="text" style="color: ${disTextColor};">${explain}</div>
                        </li>
                   </ul>
                </div>
            `;

            return `<div class="glpb-newer-list-item">${html}</div>`;
        }
    }
);


module.exports = NewerItem;