const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

const lpService = serviceFactory.getService('lp');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;

const tpl = `<div class="glpb-select-image"><div class="glpb-content"></div></div>`;


const IosSelect = require('./iosSelect/iosSelect.js');
require('./iosSelect/iosSelect.css');
require('./select-image.scss');

const editorPlaceHolderImage = '//m.we.com/cms/58647d50e0286a10854d875a/pagebuilder/history.png';

const SelectImage = BaseComponent.extend({
    componentName : 'glpb_we_com_select_image',
    componentNameZh : '图片选择',
    componentCategory : BaseComponent.CATEGORY.UI,
    platform : BaseComponent.PLATFORM.MOBILE,
    canBeChildOfComponentName : function(){
        return true;
    }
}, {
    getDefaultStyle : function(){
        return {
            background : {
                backgroundColor : 'none'
            },
            padding : '0',
            margin : '0 auto'
        };
    },

    getDefaultData : function(){

        return {
            "options_$$comment": '选择菜单初始数据, value为显示文字, url为图片地址, id唯一',
            options: [
                    {
                        "url": "//172.16.3.119/cms/5772b3bd7c2e49572e21acaa/we_history_recommend/6.png",
                        "value": "2017年09月"
                    }
                ],
            "defaultDataIndex_$$comment": '默认显式第几项(从0开始)',
            defaultDataIndex: 0,
            title: "优选产品收益率分布",
            subtitle: "收益率(%)"
        };
    },

    init : function () {
    },

    render : function(){
        let currentComponentId = this.componentId;

        let cssClass = this.getBaseCssClass() + '  ';
        let cssStyle = this.translateStyle( this.style );
        let $el = $(tpl).addClass( cssClass ).css( cssStyle );;
        let $content = $('.glpb-content', $el);

        this.$el = $el;
        this.$content = $content;

        if( ! this.isProductionMode() ){
            //编辑模式, 显示一个图片占位
            $(`<img class="editor-place-holder-img" width="100%" src="${editorPlaceHolderImage}" title="历史推荐日期选择组件(非真实数据)" />`).appendTo( $content );
        }
    },

    bindComponentEvent: function () {
        let _this = this;
        let data = this.data || {};
        // 日期组件需要的数据
        let index = data.defaultDataIndex;
        let defaultData = data.options[index];
        let options = data.options;
        // 添加id
        for (let i = 0; i < options.length; i++) {
            options[i].id = i;
        }

        this.$content.html(`<div class="profit-wrap">
                                <div class="title">${data.title}</div>
                                <div class="split"></div>
                                <div class="img-title">
                                    <div class="rate">${data.subtitle}</div>
                                    <div class="date-wrap" id="select-option">
                                        <div class="date">${defaultData.value}</div>
                                        <div class="triangle"></div>
                                    </div>
                                </div>
                            </div>
                            <div class="profit-img"><img src="${defaultData.url}" /></div>    
                           `);

        let selectDom = document.getElementById('select-option');
        $('#select-option').bind('click', function () {
            let iosSelect = new IosSelect(1,
                [options],
                {
                    title: '选择日期',
                    itemHeight: 0.7,
                    headerHeight: 0.88,
                    oneLevelId: selectDom.dataset['select'],
                    cssUnit: 'rem',
                    callback: function (selectObj) {
                        _this.changeDate(selectObj);
                    }
                });
        });
    },

    changeDate: function (selectObj) {
        let options = this.data.options;
        let selectDom = document.getElementById('select-option');
        selectDom.dataset['select'] = selectObj.id;

        // 设置日期
        $('.profit-wrap .date').html(selectObj.value);
        // 设置图片
        $('.profit-img img').attr({'src': selectObj.url});
    }

});

module.exports = SelectImage;

