/**
 * 渲染统计数据页卡
 * Created by qiangran on 2016/12/09.
 */



const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

const lpService = serviceFactory.getService('lp');


require('./statistics-box.scss');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;



const tpl = `<div class="glpb-fn-animate-item"><div class="glpb-content"></div></div>`;

const editorPlaceHolderImage = '//m.we.com/cms/5864b392e0286a10854d8766/register/statistic/statistic-02.png';


const StatisticBox = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_mo_statistic_box',
        componentNameZh : 'MO-统计数据',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.MOBILE,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                padding : '0',
                margin : '0'
            };
        },

        getDefaultData : function(){
            return {
                "textColor_$$comment" : '文字颜色。可配置【累计服务用户数超、累计成交额超、万、亿】颜色',
                textColor : '#828aa5',
                "numberColor_$$comment" : '数字的颜色',
                numberColor : '#fe7437'
            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
        },

        render : function(){

            let currentComponentId = this.componentId;
            let data = this.data;

            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );;
            let $content = $('.glpb-content', $el);

            this.$el = $el;
            this.$content = $content;

            if( ! this.isProductionMode() ){
                //编辑模式, 显示一个图片占位
                $(`<img class="editor-place-holder-img" src="${editorPlaceHolderImage}" title="统计数据页卡占位图片(非真实数据)" />`).appendTo( $content );
            }
        },

        bindComponentEvent : function(){

            let that = this;
            let configData = this.data || {};


            if( this.isProductionMode() && ! this.eventBinded ){

                this.eventBinded = true;

                lpService.pbStatistic( {} ).then( ( reqResult ) => {
                    if( reqResult.requestStatus === lpService.STATUS.SUCCESS ){
                        let result = reqResult.data;
                        if( result.status === 0 ){
                            that.renderStatisticsDom(result.data ,configData);
                            return;
                        }
                        return Promise.reject(new Error(result.message));
                    }
                    return Promise.reject( new Error('获取统计数据异常!'));
                })
                .catch( (e) => {
                    console.log(e);
                    alert(e.message);
                });
            }
        },

        renderStatisticsDom : function(data,configData){
            let  textColor = configData.textColor;
            let  numberColor = configData.numberColor;
            let textStyle= `color:${textColor}`;
            let numberStyle= `color:${numberColor}`;

            let  tradeAmountArr = data.tradeAmountArr;
            let  userTotalCountArr = data.userTotalCountArr;
            let userTotalDom = userTotalCountArr.map(function(data){
                return `<dd style=${numberStyle}>${data}</dd>`;
            }).join('');

            let tradeAmountDom = tradeAmountArr.map(function(data){
                return `<dd style=${numberStyle}>${data}</dd>`;
            }).join('');

            let html = `
                <div class="ui-statisic-box">
                    <div class="people-box">
                        <div class="people-box-info">
                            <p class="text" style=${textStyle}>累计注册用户数超</p>
                            <dl class="number">
                                ${userTotalDom}
                            </dl>
                        </div>
                        <div class="unit" style=${textStyle}>万</div>
                    </div>
                    <div class="trade-box">
                         <div class="trade-box-info">
                             <p class="text" style=${textStyle}>累计成交额超</p>
                             <dl class="number">
                                     ${tradeAmountDom}
                              </dl>
                         </div>
                         <div class="unit" style=${textStyle}>亿</div>
                    </div>
                </div>
            `;

            if( html ) {

                this.$content.html(`<div class="glpb-ui-statisic-box">${html}</div>`);
            }
        },


        componentWillUnmount : function(){
            this.$content = null;
        }

    }
);


module.exports = StatisticBox;