/**
 * U享计划
 * add by liucong in 2019-04-01
 **/

const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

const lpService = serviceFactory.getService('lp');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;

const tpl = `<div class="glpb-mobile-uplan-item"><div class="glpb-content"></div></div>`;

require('./uplan-item.scss');

const editorPlaceHolderImage = 'https://s0.renrendai.com/cms/58647d50e0286a10854d875a/lp/placeholder/uplan.png';

const NewerItem = BaseComponent.extend(
    {
        componentName : 'glpb-com-glpb_we_com_uplan_item',
        componentNameZh : 'U享计划',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.MOBILE,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                background : {
                    backgroundColor : 'none'
                },
                padding : '0',
                margin : '0 auto'
            };
        },

        getDefaultData : function(){
            return {
                "productType_$$comment" : '产品类型，可选值：A-1、A-3、A-6、A-12、A-24、A-36，分别代表对应月份的U享计划',
                productType : 'A-12',
                "bgImageUrl_$$comment" : '背景图【图片大小必须为650*250】',
                bgImageUrl : 'https://s0.renrendai.com/cms/58647d50e0286a10854d875a/lp/placeholder/uplan_bg_orange.png',
                "rateColor_$$comment" : '利率的字体颜色',
                rateColor : '#ff7f31',
                "rateText_$$comment": '利率下方文案',
                rateText: '扣费后年利率',
                "lockPeriodColor_$$comment" : '右侧固定服务期的字体颜色',
                lockPeriodColor : '#333',
                "lockPeriodText_$$comment": '服务期文案 XX表示期限(XX大写，从后端取值)',
                lockPeriodText: 'XX个月服务期限',
                "disTextColor_$$comment" : '字段描述的文字颜色',
                disTextColor : '#666',
                "explain_$$comment" : '服务期下方的文案配置',
                explain : '分散投标，专业风控',
            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
        },

        render : function(){
            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('.glpb-content', $el);

            this.$el = $el;
            this.$content = $content;

            if( ! this.isProductionMode() ){
                //编辑模式, 显示一个图片占位
                $(`<img class="editor-place-holder-img" width="100%" src="${editorPlaceHolderImage}" title="U享计划(非真实数据)" />`).appendTo( $content );
            }
        },

        bindComponentEvent : function(){
            let that = this;

            if( this.isProductionMode() && ! this.eventBinded ){

                this.eventBinded = true;

                this.querySign = utils.generateQuerySign();

                let productType = this.data.productType;

                lpService.uplan({productType}).then( ( reqResult ) => {
                    if( reqResult.requestStatus === lpService.STATUS.SUCCESS ){
                        let result = reqResult.data;
                        if( result.status === 0 ){
                            that.setUPlanData( result.data );
                            return;
                        }
                        return Promise.reject(new Error(result.message));
                    }
                    return Promise.reject( new Error('获取优选数据异常!'));
                })
                .catch( (e) => {
                    console.log(e.message);
                    that.hide();
                });

            }
        },

        componentWillUnmount : function(){
            this.$content = null;
        },

        setUPlanData : function(data){
            let list = data.list;
            list = list || [];
            if( ! list || list.length < 1 ){
                return this.hide();
            }
            let html = this._renderItem( list[0] );
            if( html ){
                this.$content.html( html );
            }else{
                this.hide();
            }
        },

        formatRate:function(rate){
            //格式化利率，保留一位小数
            if (typeof rate == 'number') {
                rate = rate+'';
            }
            let index = rate.indexOf('.');
            rate = rate.substr(0,index+2);
            if( rate && rate.indexOf('.') < 0 ){
                rate += '.0';
            }
            return rate;
        },

        _renderItem : function( financePlanVos ){
            let data = this.data || {};
            let bgImageUrl = data.bgImageUrl;
            let rateColor = data.rateColor;
            let lockPeriodColor = data.lockPeriodColor;
            let disTextColor = data.disTextColor;
            let rateText = data.rateText;
            let filedDom = data.lockPeriodText.replace('XX',financePlanVos.lockPeriod);
            let rateDom = `${financePlanVos.expectedYearRate}<span>%</span>`;
            let baseInterestRate = this.formatRate(financePlanVos.baseInterestRate);
            let extraInterestRate = this.formatRate(financePlanVos.extraInterestRate);
            if(extraInterestRate != '0.0'){
                rateDom = `${baseInterestRate}<span>%+${extraInterestRate}%</span>`;
            }

            let explainText = data.explain.replace('XX',financePlanVos.expectedYearRate);

            let html = `
                <div class="uplan-item-box" style="background: url('${bgImageUrl}') no-repeat; background-size: 100% 100%;">     
                   <ul class="uplan-data fn-clear">
                        <li class="uplan-left">
                            <div class="rate" style="color: ${rateColor};">${rateDom}</div>
                            <div class="text" style="color: ${disTextColor};">${rateText}</div>
                        </li>
                        <li class="uplan-right">
                            <div class="rate" style="color: ${lockPeriodColor};">${filedDom}</div>
                            <div class="text" style="color: ${disTextColor};">${explainText}</div>
                        </li>
                   </ul>
                </div>
            `;

            return `<div class="glpb-uplan-item-box">${html}</div>`;
        }
    }
);


module.exports = NewerItem;